@@ -25,12 +25,12 @@ package Ftree::Cemetery;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('2.3.28');
+use version; our $VERSION = qv('2.3.29');
 
 use Ftree::Place;
 use Params::Validate qw(:all);
 
-use base 'Place';
+use base 'Ftree::Place';
 sub new {
     my $type = shift;
     my $self = $type->SUPER::new(@_);
@@ -44,4 +44,4 @@ sub new {
       return defined $self->{cemetery} ? "$string, $self->{cemetery}" : $string;
  }
 
- 1;
\ No newline at end of file
+ 1;
